@@ -553,6 +553,7 @@ class MediaMixin:
                 f"feed/user/{user_id}/",
                 params={
                     "max_id": next_max_id,
+                    "count": 1000,
                     "min_timestamp": min_timestamp,
                     "rank_token": self.rank_token,
                     "ranked_content": "true",
@@ -563,7 +564,8 @@ class MediaMixin:
             return [], None
         medias.extend(items)
         next_max_id = self.last_json.get("next_max_id", "")
-        medias = medias[:amount]
+        if amount:
+            medias = medias[:amount]
         return (
             [extract_media_v1(media) for media in medias],
             next_max_id
